@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -36,6 +36,7 @@ import org.eclipse.osgi.util.NLS;
 
 public class Messages extends NLS {
 	private static final String BUNDLE_NAME = "org.openjdk.jmc.flightrecorder.ui.messages.internal.messages"; //$NON-NLS-1$
+	public static String AgentsPage_PAGE_NAME;
 	public static String ATTRIBUTE_CONFIG_PAGE_RULES;
 	public static String ATTRIBUTE_CONFIG_RULE;
 	public static String ATTRIBUTE_CONFIG_RULES;
@@ -166,6 +167,7 @@ public class Messages extends NLS {
 	public static String FileIOPage_PERCENTILE_SELECTION;
 	public static String FileIOPage_ROW_FILE_READ;
 	public static String FileIOPage_ROW_FILE_WRITE;
+	public static String FileIOPage_ROW_FILE_FORCE;
 	public static String FileIOPage_SELECTED_PATH;
 	public static String FileIOPage_SELECTED_PATHS;
 	public static String FileIOPage_TIMELINE_SELECTION;
@@ -298,6 +300,7 @@ public class Messages extends NLS {
 	public static String JFR_EDITOR_RULES_CANCELLED;
 	public static String JFR_EDITOR_RULES_EVALUATING;
 	public static String JFR_EDITOR_RULES_IGNORED;
+	public static String JFR_EDITOR_RULES_IGNORED_REASON;
 	public static String JFR_EDITOR_RULES_SCHEDULED;
 	public static String JFR_EDITOR_RULES_TASK_NAME;
 	public static String JFR_EDITOR_RULES_WAITING;
@@ -357,6 +360,10 @@ public class Messages extends NLS {
 	public static String JavaApplicationPage_ROW_CPU_USAGE;
 	public static String JavaApplicationPage_ROW_CPU_USAGE_DESC;
 	public static String JavaApplicationPage_ROW_HEAP_USAGE;
+	public static String JavaApplicationPage_ROW_RSS;
+	public static String JavaApplicationPage_ROW_RSS_DESC;
+	public static String JavaApplicationPage_ROW_THREAD_COUNTS;
+	public static String JavaApplicationPage_ROW_THREAD_COUNTS_DESC;
 	public static String JavaApplicationPage_SELECTED_THREAD;
 	public static String JavaApplicationPage_SELECTED_THREADS;
 	public static String JavaApplicationPage_THREAD_ACTIVITY_ACTION;
@@ -471,6 +478,7 @@ public class Messages extends NLS {
 	public static String RESULT_VIEW_ANALYSIS_DISABLED;
 	public static String RESULT_VIEW_NO_EDITOR_SELECTED;
 	public static String RULESPAGE_SHOW_OK_RESULTS_ACTION;
+	public static String RULESPAGE_SHOW_IGNORE_RESULTS_ACTION;
 	public static String RULES_SHOW_RESULTS_ACTION;
 	public static String RULES_STATISTICS;
 	public static String RecordingPage_CONCURRENT_RECORDINGS_SELECTION;
@@ -515,6 +523,7 @@ public class Messages extends NLS {
 	public static String STACKTRACE_VIEW_COUNT_COLUMN_NAME;
 	public static String STACKTRACE_VIEW_PERCENTAGE_COLUMN_NAME;
 	public static String STACKTRACE_VIEW_PERCENTAGE_BY_DURATION_COLUMN_NAME;
+	public static String STACKTRACE_VIEW_DURATION_COLUMN_NAME;
 	public static String STACKTRACE_VIEW_DISTINGUISH_FRAMES_BY;
 	public static String STACKTRACE_VIEW_FRAME_GROUP_CHOOSE;
 	public static String STACKTRACE_VIEW_FRAME_GROUP_NEXT;
@@ -528,7 +537,7 @@ public class Messages extends NLS {
 	public static String STACKTRACE_VIEW_REDUCE_TREE_DEPTH;
 	public static String STACKTRACE_VIEW_SELECTION;
 	public static String STACKTRACE_VIEW_TREE_VIEW;
-	public static String STACKTRACE_VIEW_PERCENTAGE_BY_DURATION;
+	public static String STACKTRACE_VIEW_DURATION;
 	public static String STACKTRACE_VIEW_STACK_TRACE;
 	public static String STACKTRACE_VIEW_THREAD_ROOT;
 	public static String STACKTRACE_VIEW_TRACES_IN_GROUP;
@@ -537,6 +546,8 @@ public class Messages extends NLS {
 	public static String STACKTRACE_VIEW_TRACE_IN_GROUP;
 	public static String STACKTRACE_VIEW_TRACE_IN_GROUPS;
 	public static String STACKTRACE_VIEW_TRACE_OF_TOTAL;
+	public static String STACKTRACE_VIEW_TRACE_OF_TOTAL_COUNT;
+	public static String STACKTRACE_VIEW_TRACES_OF_TOTAL_COUNT;
 	public static String STORED_SELECTIONS_SIZE_LESS_THAN_ZERO;
 	public static String STORED_SELECTIONS_SIZE_PREF;
 	public static String STORED_SELECTIONS_SIZE_UNPARSABLE;
@@ -612,6 +623,7 @@ public class Messages extends NLS {
 	public static String VMOperationPage_PAGE_NAME;
 	public static String VMOperationPage_ROW_VM_OPERATIONS;
 	public static String VMOperationPage_TIMELINE_SELECTION;
+	public static String ThreadsPage_LANE_THREAD_ID_TOOLTIP;
 
 	static {
 		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
@@ -623,9 +635,9 @@ public class Messages extends NLS {
 	public static String stackTraceMessage(int itemCount, int totalCount, String frameFraction) {
 		String message;
 		if (itemCount == 1) {
-			message = Messages.STACKTRACE_VIEW_TRACE_OF_TOTAL;
+			message = Messages.STACKTRACE_VIEW_TRACE_OF_TOTAL_COUNT;
 		} else {
-			message = Messages.STACKTRACE_VIEW_TRACES_OF_TOTAL;
+			message = Messages.STACKTRACE_VIEW_TRACES_OF_TOTAL_COUNT;
 		}
 		return NLS.bind(message, new Object[] {itemCount, frameFraction, totalCount});
 	}
@@ -648,13 +660,15 @@ public class Messages extends NLS {
 		return NLS.bind(message, itemsInSiblings, nSiblings);
 	}
 
-	public static String stackTraceMessage(double duration, double totalDuration, String frameFraction) {
+	public static String stackTraceMessage(
+		double duration, String durationUnit, double totalDuration, String totalDurationUnit, String frameFraction) {
 		String message;
 		if (duration == 1) {
 			message = Messages.STACKTRACE_VIEW_TRACE_OF_TOTAL;
 		} else {
 			message = Messages.STACKTRACE_VIEW_TRACES_OF_TOTAL;
 		}
-		return NLS.bind(message, new Object[] {duration, frameFraction, totalDuration});
+		return NLS.bind(message,
+				new Object[] {duration, durationUnit, frameFraction, totalDuration, totalDurationUnit});
 	}
 }
