@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  * 
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -350,6 +350,8 @@ public class EventBrowserPage extends AbstractDataPage {
 					newColumns.add(0, new ColumnSettings(combinedId, false, null, null));
 				}
 			});
+			// add a column for the event type id, hidden by default
+			itemListBuilder.addColumn(JfrAttributes.EVENT_TYPE_ID);
 			listColumns.addAll(0, newColumns);
 
 			saveFilterActionStates();
