@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2021 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  * 
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -263,6 +263,12 @@ public class JavaApplicationPage extends AbstractDataPage {
 					Messages.JavaApplicationPage_ROW_CPU_USAGE_DESC, allItems, true, JdkQueries.CPU_USAGE_SIMPLE_QUERY,
 					this::isAttributeEnabled, UnitLookup.PERCENT.quantity(0), UnitLookup.PERCENT.quantity(100))
 					.ifPresent(rows::add);
+			DataPageToolkit.buildLinesRow(Messages.JavaApplicationPage_ROW_THREAD_COUNTS,
+					Messages.JavaApplicationPage_ROW_THREAD_COUNTS_DESC, allItems, false, JdkQueries.THREAD_STATISTICS,
+					this::isAttributeEnabled, UnitLookup.NUMBER_UNITY.quantity(0), null).ifPresent(rows::add);
+			DataPageToolkit.buildLinesRow(Messages.JavaApplicationPage_ROW_RSS,
+					Messages.JavaApplicationPage_ROW_RSS_DESC, allItems, true, JdkQueries.RSS_SIMPLE_QUERY,
+					this::isAttributeEnabled, UnitLookup.BYTE.quantity(0), null).ifPresent(rows::add);
 			DataPageToolkit.buildLinesRow(Messages.JavaApplicationPage_ROW_HEAP_USAGE,
 					JdkAttributes.HEAP_USED.getDescription(), allItems, false, JdkQueries.HEAP_SUMMARY,
 					this::isAttributeEnabled, UnitLookup.BYTE.quantity(0), null).ifPresent(rows::add);
@@ -325,7 +331,9 @@ public class JavaApplicationPage extends AbstractDataPage {
 					FlightRecorderUI.getDefault().getMCImageDescriptor(ImageConstants.ICON_STOP), b -> buildChart());
 			Stream<IAction> attributeActions = Stream
 					.concat(JdkQueries.CPU_USAGE_SIMPLE_QUERY.getAttributes().stream(),
-							Stream.of(JdkAttributes.HEAP_USED))
+							Stream.concat(JdkQueries.THREAD_STATISTICS.getAttributes().stream(),
+									Stream.concat(JdkQueries.RSS_SIMPLE_QUERY.getAttributes().stream(),
+											Stream.of(JdkAttributes.HEAP_USED))))
 					.map(a -> DataPageToolkit.createAttributeCheckAction(a, b -> buildChart()));
 
 			// FIXME: Consider using a custom tooltip instead where the color could be shown graphically.
