@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  * 
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -32,6 +32,7 @@
  */
 package org.openjdk.jmc.flightrecorder.ui.views.stacktrace;
 
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -72,6 +73,8 @@ import org.eclipse.jface.viewers.ViewerCell;
 import org.eclipse.jface.viewers.ViewerColumn;
 import org.eclipse.jface.window.ToolTip;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.dnd.TextTransfer;
+import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.events.TraverseEvent;
 import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.graphics.Color;
@@ -104,10 +107,12 @@ import org.openjdk.jmc.common.item.IType;
 import org.openjdk.jmc.common.item.ItemCollectionToolkit;
 import org.openjdk.jmc.common.item.ItemFilters;
 import org.openjdk.jmc.common.unit.IQuantity;
+import org.openjdk.jmc.common.unit.QuantityConversionException;
 import org.openjdk.jmc.common.unit.UnitLookup;
 import org.openjdk.jmc.common.util.Pair;
 import org.openjdk.jmc.common.util.StateToolkit;
 import org.openjdk.jmc.flightrecorder.JfrAttributes;
+import org.openjdk.jmc.flightrecorder.serializers.stacktraces.CollapsedSerializer;
 import org.openjdk.jmc.flightrecorder.stacktrace.FrameSeparator;
 import org.openjdk.jmc.flightrecorder.stacktrace.FrameSeparator.FrameCategorization;
 import org.openjdk.jmc.flightrecorder.stacktrace.StacktraceFormatToolkit;
@@ -115,6 +120,7 @@ import org.openjdk.jmc.flightrecorder.stacktrace.StacktraceFrame;
 import org.openjdk.jmc.flightrecorder.stacktrace.StacktraceModel;
 import org.openjdk.jmc.flightrecorder.stacktrace.StacktraceModel.Branch;
 import org.openjdk.jmc.flightrecorder.stacktrace.StacktraceModel.Fork;
+import org.openjdk.jmc.flightrecorder.stacktrace.tree.StacktraceTreeModel;
 import org.openjdk.jmc.flightrecorder.ui.FlightRecorderUI;
 import org.openjdk.jmc.flightrecorder.ui.IPageContainer;
 import org.openjdk.jmc.flightrecorder.ui.common.AttributeSelection;
@@ -128,12 +134,14 @@ import org.openjdk.jmc.ui.CoreImages;
 import org.openjdk.jmc.ui.UIPlugin;
 import org.openjdk.jmc.ui.accessibility.FocusTracker;
 import org.openjdk.jmc.ui.common.util.AdapterUtil;
+import org.openjdk.jmc.ui.common.util.ThemeUtils;
 import org.openjdk.jmc.ui.handlers.ActionToolkit;
 import org.openjdk.jmc.ui.handlers.CopySelectionAction;
 import org.openjdk.jmc.ui.handlers.InFocusHandlerActivator;
 import org.openjdk.jmc.ui.handlers.MCContextMenuManager;
 import org.openjdk.jmc.ui.handlers.MethodFormatter;
 import org.openjdk.jmc.ui.misc.AbstractStructuredContentProvider;
+import org.openjdk.jmc.ui.misc.ClipboardManager;
 import org.openjdk.jmc.ui.misc.CompositeToolkit;
 import org.openjdk.jmc.ui.misc.CopySettings;
 import org.openjdk.jmc.ui.misc.DisplayToolkit;
@@ -186,13 +194,29 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		}
 	}
 
+	private class ExportCollpasedAction extends Action {
+		ExportCollpasedAction() {
+			super("Collapsed");
+		}
+
+		@Override
+		public void run() {
+			System.err.println("Export to collapsed");
+			String content = CollapsedSerializer.toCollapsed(new StacktraceTreeModel(itemsToShow,
+					new FrameSeparator(FrameCategorization.METHOD, false), false, currentAttribute));
+			ClipboardManager.setClipboardContents(new Object[] {content}, new Transfer[] {TextTransfer.getInstance()});
+		}
+	}
+
 	private static final String HELP_CONTEXT_ID = FlightRecorderUI.PLUGIN_ID + ".StacktraceView"; //$NON-NLS-1$
 	// FIXME: Define dynamic color (editable in preferences, to handle dark themes etc.)
 	private static final Color ALTERNATE_COLOR = SWTColorToolkit.getColor(new RGB(255, 255, 240));
 	private static final String COUNT_IMG_KEY = "countColor"; //$NON-NLS-1$
 	private static final Color COUNT_COLOR = SWTColorToolkit.getColor(new RGB(100, 200, 100));
+	private static final Color COUNT_COLOR_DARK_MODE = SWTColorToolkit.getColor(new RGB(7, 94, 7));
 	private static final String SIBLINGS_IMG_KEY = "siblingsColor"; //$NON-NLS-1$
 	private static final Color SIBLINGS_COUNT_COLOR = SWTColorToolkit.getColor(new RGB(170, 250, 170));
+	private static final Color SIBLINGS_COUNT_COLOR_DARK_MODE = SWTColorToolkit.getColor(new RGB(8, 115, 8));
 	private static final int[] DEFAULT_COLUMN_WIDTHS = {650, 80, 120};
 	private static final String THREAD_ROOT_KEY = "threadRootAtTop"; //$NON-NLS-1$
 	private static final String FRAME_OPTIMIZATION_KEY = "distinguishFramesByOptimization"; //$NON-NLS-1$
@@ -425,8 +449,8 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		treeAction.setChecked(treeLayout);
 		layoutActions = new IAction[] {treeAction, reducedTreeAction};
 
-		IAction perByDurationAction = ActionToolkit.checkAction(this::setPerDuration,
-				Messages.STACKTRACE_VIEW_PERCENTAGE_BY_DURATION, CoreImages.TIMESPAN);
+		IAction perByDurationAction = ActionToolkit.checkAction(this::setPerDuration, Messages.STACKTRACE_VIEW_DURATION,
+				CoreImages.TIMESPAN);
 		treeAction.setChecked(perDuration);
 
 		NavigateAction forwardAction = new NavigateAction(true);
@@ -571,11 +595,11 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		CopySelectionAction copyAction;
 		if (perDuration) {
 			headers = Arrays.asList(Messages.STACKTRACE_VIEW_STACK_TRACE, Messages.STACKTRACE_VIEW_COUNT_COLUMN_NAME,
-					Messages.STACKTRACE_VIEW_PERCENTAGE_COLUMN_NAME,
+					Messages.STACKTRACE_VIEW_PERCENTAGE_COLUMN_NAME, Messages.STACKTRACE_VIEW_DURATION_COLUMN_NAME,
 					Messages.STACKTRACE_VIEW_PERCENTAGE_BY_DURATION_COLUMN_NAME);
 			copyAction = new CopySelectionAction(viewer,
 					FormatToolkit.selectionFormatter(headers, stackTraceLabelProvider, countLabelProvider,
-							percentageLabelProvider, percentageByDurationLabelProvider));
+							percentageLabelProvider, durationLabelProvider, percentageByDurationLabelProvider));
 		} else {
 			headers = Arrays.asList(Messages.STACKTRACE_VIEW_STACK_TRACE, Messages.STACKTRACE_VIEW_COUNT_COLUMN_NAME,
 					Messages.STACKTRACE_VIEW_PERCENTAGE_COLUMN_NAME);
@@ -609,9 +633,13 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		valueColumn.setLabelProvider(countLabelProvider);
 		buildColumn(viewer, Messages.STACKTRACE_VIEW_PERCENTAGE_COLUMN_NAME, SWT.RIGHT, columnWidths[2])
 				.setLabelProvider(percentageLabelProvider);
-		if (perDuration)
+
+		if (perDuration) {
+			buildColumn(viewer, Messages.STACKTRACE_VIEW_DURATION_COLUMN_NAME, SWT.RIGHT, 300)
+					.setLabelProvider(durationLabelProvider);
 			buildColumn(viewer, Messages.STACKTRACE_VIEW_PERCENTAGE_BY_DURATION_COLUMN_NAME, SWT.RIGHT, 300)
 					.setLabelProvider(percentageByDurationLabelProvider);
+		}
 		PlatformUI.getWorkbench().getHelpSystem().setHelp(viewer.getControl(), HELP_CONTEXT_ID);
 
 		if (UIPlugin.getDefault().getAccessibilityMode()) {
@@ -685,6 +713,11 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		menu.appendToGroup(MCContextMenuManager.GROUP_VIEWER_SETUP, methodFormatter.createMenu());
 		SelectionStoreActionToolkit.addSelectionStoreActions(viewer, this::getSelectionStore,
 				this::getFlavoredSelection, menu);
+		MenuManager exportMenu = new MenuManager("Export stacktraces");
+		exportMenu.setRemoveAllWhenShown(true);
+		exportMenu.addMenuListener((manager) -> manager.add(new ExportCollpasedAction()));
+		menu.appendToGroup(MCContextMenuManager.GROUP_EDIT, exportMenu);
+
 	}
 
 	private IFlavoredSelection getFlavoredSelection() {
@@ -830,12 +863,13 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 				long forkOffset = parentFork.getItemOffset();
 				int siblingsStart = (int) Math.floor(event.width * forkOffset / total);
 				int siblingsWidth = (int) Math.round(event.width * parentFork.getAggregateItemsInFork() / total);
-				event.gc.setBackground(SIBLINGS_COUNT_COLOR);
+				event.gc.setBackground(
+						ThemeUtils.isDarkTheme() ? SIBLINGS_COUNT_COLOR_DARK_MODE : SIBLINGS_COUNT_COLOR);
 				event.gc.fillRectangle(event.x + siblingsStart, event.y, siblingsWidth, event.height);
 				// Draw group
 				double offset = (forkOffset + frame.getBranch().getItemOffsetInFork()) / total;
 				double fraction = frame.getAttributeAggregate() / total;
-				event.gc.setBackground(COUNT_COLOR);
+				event.gc.setBackground(ThemeUtils.isDarkTheme() ? COUNT_COLOR_DARK_MODE : COUNT_COLOR);
 				int startPixel = (int) Math.floor(event.width * offset);
 				int widthPixel = (int) Math.round(event.width * fraction);
 				event.gc.fillRectangle(event.x + startPixel, event.y, Math.max(widthPixel, 1), event.height);
@@ -850,18 +884,19 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 			StacktraceFrame frame = (StacktraceFrame) event.item.getData();
 			Fork rootFork = getRootFork(frame.getBranch().getParentFork());
 			double total;
-			if (event.index == 3 && (total = rootFork.getAggregateItemsInFork()) > 0) { // index == 3 => percentage (by duration) column
+			if (event.index == 4 && (total = rootFork.getAggregateItemsInFork()) > 0) { // index == 4 => percentage (by duration) column
 				// Draw siblings
 				Fork parentFork = frame.getBranch().getParentFork();
 				long forkOffset = parentFork.getItemOffset();
 				int siblingsStart = (int) Math.floor(event.width * forkOffset / total);
 				int siblingsWidth = (int) Math.round(event.width * parentFork.getAggregateItemsInFork() / total);
-				event.gc.setBackground(SIBLINGS_COUNT_COLOR);
+				event.gc.setBackground(
+						ThemeUtils.isDarkTheme() ? SIBLINGS_COUNT_COLOR_DARK_MODE : SIBLINGS_COUNT_COLOR);
 				event.gc.fillRectangle(event.x + siblingsStart, event.y, siblingsWidth, event.height);
 				// Draw group
 				double offset = (forkOffset + frame.getBranch().getItemOffsetInFork()) / total;
 				double fraction = frame.getAttributeAggregate() / total;
-				event.gc.setBackground(COUNT_COLOR);
+				event.gc.setBackground(ThemeUtils.isDarkTheme() ? COUNT_COLOR_DARK_MODE : COUNT_COLOR);
 				int startPixel = (int) Math.floor(event.width * offset);
 				int widthPixel = (int) Math.round(event.width * fraction);
 				event.gc.fillRectangle(event.x + startPixel, event.y, Math.max(widthPixel, 1), event.height);
@@ -908,8 +943,12 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 			IQuantity duration = getDurationCount(frame.getItems());
 			IQuantity totalDuration = getDurationCount(
 					getRootFork(frame.getBranch().getParentFork()).getAllItemsInFork());
-			return UnitLookup.PERCENT_UNITY.quantity(duration.doubleValue() / (double) totalDuration.doubleValue())
-					.displayUsing(IDisplayable.AUTO);
+			if (duration.doubleValue() > 0) {
+				return UnitLookup.PERCENT_UNITY.quantity(duration.doubleValue() / (double) totalDuration.doubleValue())
+						.displayUsing(IDisplayable.AUTO);
+			} else {
+				return UnitLookup.PERCENT_UNITY.quantity(0).displayUsing(IDisplayable.AUTO);
+			}
 		}
 
 		@Override
@@ -920,12 +959,18 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 			IQuantity totalDuration = getDurationCount(rootFork.getAllItemsInFork());
 			Fork parentFork = frame.getBranch().getParentFork();
 			int itemsInSiblings = parentFork.getItemsInFork() - frame.getBranch().getFirstFrame().getItemCount();
-			String frameFraction = UnitLookup.PERCENT_UNITY
-					.quantity(duration.doubleValue() / (double) totalDuration.doubleValue())
-					.displayUsing(IDisplayable.AUTO);
+			String frameFraction = "";
+			if (duration.doubleValue() > 0) {
+				frameFraction = UnitLookup.PERCENT_UNITY
+						.quantity(duration.doubleValue() / (double) totalDuration.doubleValue())
+						.displayUsing(IDisplayable.AUTO);
+			} else {
+				frameFraction = UnitLookup.PERCENT_UNITY.quantity(0).displayUsing(IDisplayable.AUTO);
+			}
 			StringBuilder sb = new StringBuilder("<form>"); //$NON-NLS-1$
 			sb.append("<li style='image' value='" + COUNT_IMG_KEY + "'><span nowrap='true'>"); //$NON-NLS-1$ //$NON-NLS-2$
-			sb.append(Messages.stackTraceMessage(duration.doubleValue(), totalDuration.doubleValue(), frameFraction));
+			sb.append(Messages.stackTraceMessage(duration.doubleValue(), duration.getUnit().getIdentifier(),
+					totalDuration.doubleValue(), totalDuration.getUnit().getIdentifier(), frameFraction));
 			sb.append("</span></li>"); //$NON-NLS-1$
 			sb.append("<li style='image' value='" + SIBLINGS_IMG_KEY + "'><span nowrap='true'>"); //$NON-NLS-1$ //$NON-NLS-2$
 			sb.append(Messages.siblingMessage(itemsInSiblings, parentFork.getBranchCount() - 1));
@@ -960,6 +1005,25 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 		}
 	};
 
+	private final ColumnLabelProvider durationLabelProvider = new ColumnLabelProvider() {
+		@Override
+		public String getText(Object element) {
+			StacktraceFrame frame = (StacktraceFrame) element;
+			IQuantity duration = getDurationCount(frame.getItems());
+			try {
+				return formatDuration(duration.longValueIn(UnitLookup.NANOSECOND));
+			} catch (QuantityConversionException e) {
+				return Messages.N_A;
+			}
+		}
+	};
+
+	private String formatDuration(long duration) {
+		Duration rawDuration = Duration.ofNanos(duration);
+		return String.format("%d h %d m %d s %d ms %d ns", rawDuration.toHoursPart(), rawDuration.toMinutesPart(),
+				rawDuration.toSecondsPart(), rawDuration.toMillisPart(), rawDuration.toNanosPart() % 1000000L);
+	}
+
 	private final ColumnLabelProvider stackTraceLabelProvider = new ColumnLabelProvider() {
 
 		@Override
@@ -998,7 +1062,7 @@ public class StacktraceView extends ViewPart implements ISelectionListener {
 
 		@Override
 		public Color getBackground(Object element) {
-			if (treeLayout) {
+			if (treeLayout || ThemeUtils.isDarkTheme()) {
 				return null;
 			} else {
 				int parentCount = 0;
