@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -140,17 +140,27 @@ public class Aggregators {
 		double sum = 0.0;
 		IUnit unit = null;
 
+		Predicate<Double> predicate;
+
 		SumConsumer(IMemberAccessor<? extends IQuantity, IItem> accessor) {
 			super(accessor);
 		}
 
+		SumConsumer(IMemberAccessor<? extends IQuantity, IItem> accessor, Predicate<Double> predicate) {
+			this(accessor);
+			this.predicate = predicate;
+		}
+
 		@Override
 		public void consume(IItem item) {
 			IQuantity fieldValue = accessor.getMember(item);
 			if (unit == null) {
 				unit = fieldValue.getUnit();
 			}
-			sum += fieldValue.doubleValueIn(unit);
+			double value = fieldValue.doubleValueIn(unit);
+			if ((predicate != null && predicate.test(value)) || (predicate == null)) {
+				sum += value;
+			}
 		}
 
 		@Override
@@ -757,6 +767,31 @@ public class Aggregators {
 		throw new IllegalArgumentException("Can only use LinearKindOfQuantity"); //$NON-NLS-1$
 	}
 
+	public static IAggregator<IQuantity, ?> sum(
+		String name, String description, final String typeId, final IAttribute<IQuantity> attribute,
+		Predicate<Double> predicate) {
+		ContentType<IQuantity> contentType = attribute.getContentType();
+		if (contentType instanceof LinearKindOfQuantity) {
+			return new Sum(name, description, (LinearKindOfQuantity) contentType) {
+
+				@Override
+				public SumConsumer newItemConsumer(IType<IItem> type) {
+					return new SumConsumer(getAccessor(type), predicate);
+				}
+
+				@Override
+				protected IMemberAccessor<IQuantity, IItem> doGetAccessor(IType<IItem> type) {
+					if (type.getIdentifier().equals(typeId)) {
+						return attribute.getAccessor(type);
+					}
+					return null;
+				}
+
+			};
+		}
+		throw new IllegalArgumentException("Can only use LinearKindOfQuantity"); //$NON-NLS-1$
+	}
+
 	public static IAggregator<IQuantity, ?> sum(
 		String name, String description, LinearKindOfQuantity ct, final IAccessorFactory<IQuantity> af) {
 		return new Sum(name, description, ct) {
@@ -1058,6 +1093,31 @@ public class Aggregators {
 		};
 	}
 
+	public static <T> IAggregator<IQuantity, ?> getJvmPid(String typeId, IAttribute<T> attribute) {
+		IAggregator<Set<T>, ?> aggregator = Aggregators.distinct(attribute);
+		aggregator = filter(aggregator, ItemFilters.type(typeId));
+		return Aggregators.valueBuilderAggregator(aggregator, new IValueBuilder<IQuantity, Set<T>>() {
+			@Override
+			public IType<? super IQuantity> getValueType() {
+				return UnitLookup.NUMBER;
+			}
+
+			@Override
+			public IQuantity getValue(Set<T> source) {
+				Long value = 0L;
+				if (source.isEmpty()) {
+					return null;
+				} else {
+					Iterator<?> itr = source.iterator();
+					while (itr.hasNext()) {
+						value = Long.valueOf((String) itr.next());
+					}
+					return UnitLookup.NUMBER_UNITY.quantity(value);
+				}
+			}
+		}, attribute.getName(), attribute.getDescription());
+	}
+
 	public static <T> IAggregator<IQuantity, ?> countDistinct(
 		String name, String description, IAccessorFactory<T> attribute) {
 		return new SetAggregator<IQuantity, T>(name, description, attribute, UnitLookup.NUMBER) {
