@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -100,6 +100,8 @@ public class Messages {
 	public static final String BufferLostRuleFactory_RESULT_SOLUTION = "BufferLostRuleFactory_RESULT_SOLUTION"; //$NON-NLS-1$
 	public static final String ClassLeakingRule_CONFIG_WARNING_LIMIT = "ClassLeakingRule_CONFIG_WARNING_LIMIT"; //$NON-NLS-1$
 	public static final String ClassLeakingRule_CONFIG_WARNING_LIMIT_LONG = "ClassLeakingRule_CONFIG_WARNING_LIMIT_LONG"; //$NON-NLS-1$
+	public static final String ClassLeakingRule_CONFIG_CALCULATION_TIMEOUT = "ClassLeakingRule_CONFIG_CALCULATION_TIMEOUT"; //$NON-NLS-1$
+	public static final String ClassLeakingRule_CONFIG_CALCULATION_TIMEOUT_LONG = "ClassLeakingRule_CONFIG_CALCULATION_TIMEOUT_LONG"; //$NON-NLS-1$
 	public static final String ClassLeakingRule_NAME = "ClassLeakingRule_NAME"; //$NON-NLS-1$
 	public static final String ClassLeakingRule_RESULT_SUMMARY = "ClassLeakingRule_RESULT_SUMMARY"; //$NON-NLS-1$
 	public static final String ClassLeakingRule_RESULT_EXPLANATION = "ClassLeakingRule_RESULT_EXPLANATION"; //$NON-NLS-1$
@@ -207,6 +209,15 @@ public class Messages {
 	public static final String DuplicateFlagsRule_RESULT_EXPLANATION = "DuplicateFlagsRule_RESULT_EXPLANATION"; //$NON-NLS-1$
 	public static final String DuplicateFlagsRule_RESULT_SOLUTION = "DuplicateFlagsRule_RESULT_SOLUTION"; //$NON-NLS-1$
 	public static final String DuplicateFlagsRule_RESULT_SUMMARY_OK = "DuplicateFlagsRule_RESULT_SUMMARY_OK"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_RULE_NAME = "DynamicallyLoadedAgentsRule_RULE_NAME"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_TEXT_EXPLANATION = "DynamicallyLoadedAgentsRule_TEXT_EXPLANATION"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_TEXT_OK = "DynamicallyLoadedAgentsRule_TEXT_OK"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_TEXT_SOLUTION = "DynamicallyLoadedAgentsRule_TEXT_SOLUTION"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_TEXT_SUMMARY = "DynamicallyLoadedAgentsRule_TEXT_SUMMARY"; //$NON-NLS-1$
+	public static final String DynamicallyLoadedAgentsRule_JAVA_WARNING_LIMIT = "DynamicallyLoadedAgentsRule_JAVA_WARNING_LIMIT"; //$NON-NLS-1$;
+	public static final String DynamicallyLoadedAgentsRule_JAVA_WARNING_LIMIT_LONG = "DynamicallyLoadedAgentsRule_JAVA_WARNING_LIMIT_LONG"; //$NON-NLS-1$;
+	public static final String DynamicallyLoadedAgentsRule_NATIVE_WARNING_LIMIT = "DynamicallyLoadedAgentsRule_NATIVE_WARNING_LIMIT"; //$NON-NLS-1$;
+	public static final String DynamicallyLoadedAgentsRule_NATIVE_WARNING_LIMIT_LONG = "DynamicallyLoadedAgentsRule_NATIVE_WARNING_LIMIT_LONG"; //$NON-NLS-1$;
 	public static final String ErrorRule_CONFIG_EXCLUDED_ERRORS = "ErrorRule_CONFIG_EXCLUDED_ERRORS"; //$NON-NLS-1$
 	public static final String ErrorRule_CONFIG_EXCLUDED_ERRORS_LONG = "ErrorRule_CONFIG_EXCLUDED_ERRORS_LONG"; //$NON-NLS-1$
 	public static final String ErrorRule_CONFIG_INFO_LIMIT = "ErrorRule_CONFIG_INFO_LIMIT"; //$NON-NLS-1$
@@ -267,6 +278,24 @@ public class Messages {
 	public static final String FileWriteRuleFactory_TEXT_WARN_LONG = "FileWriteRuleFactory_TEXT_WARN_LONG"; //$NON-NLS-1$
 	public static final String FileWriteRule_CONFIG_WARNING_LIMIT = "FileWriteRule_CONFIG_WARNING_LIMIT"; //$NON-NLS-1$
 	public static final String FileWriteRule_CONFIG_WARNING_LIMIT_LONG = "FileWriteRule_CONFIG_WARNING_LIMIT_LONG"; //$NON-NLS-1$
+	public static final String FileForceRuleFactory_RULE_NAME = "FileForceRuleFactory_RULE_NAME"; //$NON-NLS-1$
+	public static final String FileForceRuleFactory_TEXT_NO_EVENTS = "FileForceRuleFactory_TEXT_NO_EVENTS"; //$NON-NLS-1$
+	public static final String FileForceRuleFactory_TEXT_OK = "FileForceRuleFactory_TEXT_OK"; //$NON-NLS-1$
+	public static final String FileForceRuleFactory_TEXT_WARN = "FileForceRuleFactory_TEXT_WARN"; //$NON-NLS-1$
+	public static final String FileForceRuleFactory_TEXT_WARN_LONG = "FileForceRuleFactory_TEXT_WARN_LONG"; //$NON-NLS-1$
+	public static final String FileForceRule_CONFIG_INFO_LIMIT = "FileForceRule_CONFIG_INFO_LIMIT"; //$NON-NLS-1$
+	public static final String FileForceRule_CONFIG_INFO_LIMIT_LONG = "FileForceRule_CONFIG_INFO_LIMIT_LONG"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_CONFIG_FINALIZABLE_CLASSES_INCLUDE_REGEXP = "FinalizersRunRule_CONFIG_FINALIZABLE_CLASSES_INCLUDE_REGEXP"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_CONFIG_FINALIZABLE_CLASSES_INCLUDE_REGEXP_DESC = "FinalizersRunRule_CONFIG_FINALIZABLE_CLASSES_INCLUDE_REGEXP_DESC"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_EXPLANATION = "FinalizersRunRule_EXPLANATION"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_RESULT_FINALIZERS_RUN_CLASSES = "FinalizersRunRule_RESULT_FINALIZERS_RUN_CLASSES"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_RESULT_FINALIZERS_RUN_CLASSES_DESC = "FinalizersRunRule_RESULT_FINALIZERS_RUN_CLASSES_DESC"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_RESULT_FINALIZERS_RUN_COUNT = "FinalizersRunRule_RESULT_FINALIZERS_RUN_COUNT"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_RESULT_FINALIZERS_RUN_COUNT_DESC = "FinalizersRunRule_RESULT_FINALIZERS_RUN_COUNT_DESC"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_RULE_NAME = "FinalizersRunRule_RULE_NAME"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_SOLUTION = "FinalizersRunRule_SOLUTION"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_SUMMARY_OK = "FinalizersRunRule_SUMMARY_OK"; //$NON-NLS-1$
+	public static final String FinalizersRunRule_SUMMARY_WARN = "FinalizersRunRule_SUMMARY_WARN"; //$NON-NLS-1$
 	public static final String FlightRecordingSupportRule_EA_TEXT_WARN_LONG = "FlightRecordingSupportRule_EA_TEXT_WARN_LONG"; //$NON-NLS-1$
 	public static final String FlightRecordingSupportRule_EA_TEXT_WARN_SHORT = "FlightRecordingSupportRule_EA_TEXT_WARN_SHORT"; //$NON-NLS-1$
 	public static final String FlightRecordingSupportRule_NO_JVM_VERSION_EVENTS_TEXT = "FlightRecordingSupportRule_NO_JVM_VERSION_EVENTS_TEXT"; //$NON-NLS-1$
@@ -293,6 +322,9 @@ public class Messages {
 	public static final String GcFreedRatioRule_RULE_NAME = "GcFreedRatioRule_RULE_NAME"; //$NON-NLS-1$
 	public static final String GcFreedRatioRule_WINDOW_SIZE = "GcFreedRatioRule_WINDOW_SIZE"; //$NON-NLS-1$
 	public static final String GcFreedRatioRule_WINDOW_SIZE_DESC = "GcFreedRatioRule_WINDOW_SIZE_DESC"; //$NON-NLS-1$
+	public static final String GcInvertedParallelism_RULE_NAME = "GcInvertedParallelism_RULE_NAME"; //$NON-NLS-1$
+	public static final String GcInvertedParallelism_TEXT_WARN_SHORT = "GcInvertedParallelism_TEXT_WARN_SHORT"; //$NON-NLS-1$
+	public static final String GcInvertedParallelism_TEXT_WARN_LONG = "GcInvertedParallelism_TEXT_WARN_LONG"; //$NON-NLS-1$
 	public static final String GcLockerRuleFactory_RULE_NAME = "GcLockerRuleFactory_RULE_NAME"; //$NON-NLS-1$
 	public static final String GcLockerRuleFactory_TEXT_INFO = "GcLockerRuleFactory_TEXT_INFO"; //$NON-NLS-1$
 	public static final String GcLockerRuleFactory_TEXT_INFO_LONG = "GcLockerRuleFactory_TEXT_INFO_LONG"; //$NON-NLS-1$
@@ -311,6 +343,10 @@ public class Messages {
 	public static final String GcPauseRatioRule_WARNING_LIMIT_DESC = "GcPauseRatioRule_WARNING_LIMIT_DESC"; //$NON-NLS-1$
 	public static final String GcPauseRatioRule_WINDOW_SIZE = "GcPauseRatioRule_WINDOW_SIZE"; //$NON-NLS-1$
 	public static final String GcPauseRatioRule_WINDOW_SIZE_DESC = "GcPauseRatioRule_WINDOW_SIZE_DESC"; //$NON-NLS-1$
+	public static final String GcPauseTargetRule_RULE_NAME = "GcPauseTargetRule_RULE_NAME"; //$NON-NLS-1$
+	public static final String GcPauseTargetRule_TEXT_OK = "GcPauseTargetRule_TEXT_OK"; //$NON-NLS-1$
+	public static final String GcPauseTargetRule_TEXT_WARN_SHORT = "GcPauseTargetRule_TEXT_WARN_SHORT"; //$NON-NLS-1$
+	public static final String GcPauseTargetRule_TEXT_WARN_LONG = "GcPauseTargetRule_TEXT_WARN_LONG"; //$NON-NLS-1$
 	public static final String GcStallRule_RULE_NAME = "GcStallRule_RULE_NAME"; //$NON-NLS-1$
 	public static final String GcStallRule_TEXT_OK = "GcStallRule_TEXT_OK"; //$NON-NLS-1$
 	public static final String General_CONFIG_CLASS_LIMIT = "General_CONFIG_CLASS_LIMIT"; //$NON-NLS-1$
@@ -453,6 +489,15 @@ public class Messages {
 	public static final String MethodProfilingRule_WINDOW_SIZE_DESC = "MethodProfilingRule_WINDOW_SIZE_DESC"; //$NON-NLS-1$
 	public static final String MethodProfilingRule_EXCLUDED_PACKAGES = "MethodProfilingRule_EXCLUDED_PACKAGES"; //$NON-NLS-1$
 	public static final String MethodProfilingRule_EXCLUDED_PACKAGES_DESC = "MethodProfilingRule_EXCLUDED_PACKAGES_DESC"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_RULE_NAME = "MultipleAgentsRule_RULE_NAME"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_TEXT_EXPLANATION = "MultipleAgentsRule_TEXT_EXPLANATION"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_TEXT_OK = "MultipleAgentsRule_TEXT_OK"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_TEXT_SOLUTION = "MultipleAgentsRule_TEXT_SOLUTION"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_TEXT_SUMMARY = "MultipleAgentsRule_TEXT_SUMMARY"; //$NON-NLS-1$
+	public static final String MultipleAgentsRule_JAVA_WARNING_LIMIT = "MultipleAgentsRule_JAVA_WARNING_LIMIT"; //$NON-NLS-1$;
+	public static final String MultipleAgentsRule_JAVA_WARNING_LIMIT_LONG = "MultipleAgentsRule_JAVA_WARNING_LIMIT_LONG"; //$NON-NLS-1$;
+	public static final String MultipleAgentsRule_NATIVE_WARNING_LIMIT = "MultipleAgentsRule_NATIVE_WARNING_LIMIT"; //$NON-NLS-1$;
+	public static final String MultipleAgentsRule_NATIVE_WARNING_LIMIT_LONG = "MultipleAgentsRule_NATIVE_WARNING_LIMIT_LONG"; //$NON-NLS-1$;
 	public static final String NumberOfGcThreadsRuleFactory_TEXT_INFO = "NumberOfGcThreadsRuleFactory_TEXT_INFO"; //$NON-NLS-1$
 	public static final String NumberOfGcThreadsRuleFactory_TEXT_INFO_LONG = "NumberOfGcThreadsRuleFactory_TEXT_INFO_LONG"; //$NON-NLS-1$
 	public static final String ObjectStatisticsDataProvider_AGGR_LIVE_SIZE_INCREASE = "ObjectStatisticsDataProvider_AGGR_LIVE_SIZE_INCREASE"; //$NON-NLS-1$
@@ -602,12 +647,19 @@ public class Messages {
 	public static final String VMOperationRule_CONFIG_WARNING_LIMIT = "VMOperationRule_CONFIG_WARNING_LIMIT"; //$NON-NLS-1$
 	public static final String VMOperationRule_CONFIG_WARNING_LIMIT_LONG = "VMOperationRule_CONFIG_WARNING_LIMIT_LONG"; //$NON-NLS-1$
 	public static final String VMOperations_RULE_NAME = "VMOperations_RULE_NAME"; //$NON-NLS-1$
+	public static final String VMOperations_Duration_Operation = "VMOperations_Duration_Operation"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_RULE_NAME = "VerifyNoneRule_RULE_NAME"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_TEXT_INFO = "VerifyNoneRule_TEXT_INFO"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_TEXT_INFO_LONG = "VerifyNoneRule_TEXT_INFO_LONG"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_TEXT_OK = "VerifyNoneRule_TEXT_OK"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_WLS_TEXT_INFO = "VerifyNoneRule_WLS_TEXT_INFO"; //$NON-NLS-1$
 	public static final String VerifyNoneRule_WLS_TEXT_INFO_LONG = "VerifyNoneRule_WLS_TEXT_INFO_LONG"; //$NON-NLS-1$
+	public static final String PID1Rule_RULE_NAME = "PID1Rule_RULE_NAME"; //$NON-NLS-1$
+	public static final String PID1Rule_TEXT_OK = "PID1Rule_TEXT_OK"; //$NON-NLS-1$
+	public static final String PID1Rule_TEXT_INFO_LONG = "PID1Rule_TEXT_INFO_LONG"; //$NON-NLS-1$
+	public static final String PID1Rule_TEXT_INFO = "PID1Rule_TEXT_INFO"; //$NON-NLS-1$
+	public static final String PID1Rule_TEXT_SOLUTION = "PID1Rule_TEXT_SOLUTION"; //$NON-NLS-1$
+	public static final String PID1Rule_NO_PID = "PID1Rule_NO_PID"; //$NON-NLS-1$
 
 	private Messages() {
 	}
