@@ -1,11 +1,11 @@
 /*
- * Copyright (c) 2021, Oracle and/or its affiliates. All rights reserved.
- * Copyright (c) 2021, Datadog, Inc. All rights reserved.
+ * Copyright (c) 2021, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2021, 2025, Datadog, Inc. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -74,7 +74,7 @@ final class MetadataImpl {
 	private final Map<Integer, String> reverseStringTable = new ConcurrentSkipListMap<>();
 	private final Set<ResolvableType> unresolvedTypes = new CopyOnWriteArraySet<>();
 
-	private volatile TypesImpl types = null;
+	private volatile TypesImpl types;
 
 	MetadataImpl(ConstantPools constantPools) {
 		this.constantPools = constantPools;
