@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -35,7 +35,10 @@ package org.openjdk.jmc.flightrecorder.internal.parser.v1;
 import java.io.IOException;
 import java.lang.reflect.Field;
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -405,6 +408,10 @@ class ValueReaders {
 			return DOUBLE.equals(typeIdentifier);
 		}
 
+		static boolean isLong(String typeIdentifier) {
+			return LONG.equals(typeIdentifier);
+		}
+
 		static boolean isNumeric(String typeIdentifier) {
 			switch (typeIdentifier) {
 			case BYTE:
@@ -506,6 +513,7 @@ class ValueReaders {
 	static class ReflectiveReader extends AbstractStructReader {
 		// FIXME: Change the reflective setting of fields to avoid the conversion workarounds that some classes have to make. See JMC-5966
 
+		private final Map<String, Field> identifiersToFields;
 		// String to prefix reserved java keywords with when looking for a class field
 		private static final String RESERVED_IDENTIFIER_PREFIX = "_"; //$NON-NLS-1$
 		private final List<Field> fields;
@@ -515,6 +523,7 @@ class ValueReaders {
 		<T> ReflectiveReader(Class<T> klass, int fieldCount, ContentType<? super T> ct) {
 			super(fieldCount);
 			this.klass = klass;
+			this.identifiersToFields = IdentifierFieldCache.INSTANCE.get(klass);
 			this.ct = ct;
 			fields = new ArrayList<>(fieldCount);
 		}
@@ -562,18 +571,31 @@ class ValueReaders {
 		void addField(String identifier, String name, String description, IValueReader reader)
 				throws InvalidJfrFileException {
 			valueReaders.add(reader);
-			try {
-				try {
-					fields.add(klass.getField(identifier));
-				} catch (NoSuchFieldException e) {
-					fields.add(klass.getField(RESERVED_IDENTIFIER_PREFIX + identifier));
-				}
-			} catch (NoSuchFieldException e) {
+			Field field = identifiersToFields.get(identifier);
+			if (field == null) {
+				field = identifiersToFields.get(RESERVED_IDENTIFIER_PREFIX + identifier);
+			}
+			if (field == null) {
 				Logger.getLogger(ReflectiveReader.class.getName()).log(Level.WARNING,
 						"Could not find field with name '" + identifier + "' in reader for '" + ct.getIdentifier() //$NON-NLS-1$ //$NON-NLS-2$
 								+ "'"); //$NON-NLS-1$
-				fields.add(null);
 			}
+			fields.add(field);
+		}
+	}
+
+	static class IdentifierFieldCache extends ClassValue<Map<String, Field>> {
+
+		public static final IdentifierFieldCache INSTANCE = new IdentifierFieldCache();
+
+		@Override
+		protected Map<String, Field> computeValue(Class<?> type) {
+			Field[] fields = type.getFields();
+			Map<String, Field> map = new HashMap<>(fields.length);
+			for (Field field : fields) {
+				map.put(field.getName(), field);
+			}
+			return Collections.unmodifiableMap(map);
 		}
 	}
 }
