@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -56,6 +56,7 @@ import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.HW_THREADS;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_ADDRESS;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_FILE_BYTES_READ;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_FILE_BYTES_WRITTEN;
+import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_FILE_FORCE_METADATA;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_HOST;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_PORT;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkAttributes.IO_SOCKET_BYTES_READ;
@@ -77,6 +78,7 @@ import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.BOOLEAN_FLAG;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.CPU_INFORMATION;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.FILE_READ;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.FILE_WRITE;
+import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.FILE_FORCE;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.GC_CONF;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.GC_CONF_SURVIVOR;
 import static org.openjdk.jmc.flightrecorder.jdk.JdkTypeIDs.GC_CONF_TLAB;
@@ -113,8 +115,9 @@ public final class JdkAggregators {
 
 	// VM Info
 	public static final IAggregator<String, ?> JVM_NAME = distinctAsString(VM_INFO, JdkAttributes.JVM_NAME);
-	public static final IAggregator<IQuantity, ?> JVM_PID = min(JdkAttributes.JVM_PID.getName(), null, VM_INFO,
-			JdkAttributes.JVM_PID);
+	@Deprecated
+	public static final IAggregator<IQuantity, ?> JVM_PID = Aggregators.getJvmPid(VM_INFO, JdkAttributes.PID);
+	public static final IAggregator<String, ?> PID = distinctAsString(VM_INFO, JdkAttributes.PID);
 	public static final IAggregator<IQuantity, ?> JVM_START_TIME = min(JdkAttributes.JVM_START_TIME.getName(), null,
 			VM_INFO, JdkAttributes.JVM_START_TIME);
 	public static final IAggregator<String, ?> JVM_VERSION = distinctAsString(VM_INFO, JdkAttributes.JVM_VERSION);
@@ -177,7 +180,7 @@ public final class JdkAggregators {
 			JdkAttributes.YOUNG_GENERATION_MIN_SIZE);
 	public static final IAggregator<IQuantity, ?> YOUNG_GENERATION_MAX_SIZE = min(
 			JdkAttributes.YOUNG_GENERATION_MAX_SIZE.getName(), null, GC_CONF_YOUNG_GENERATION,
-			JdkAttributes.YOUNG_GENERATION_MIN_SIZE);
+			JdkAttributes.YOUNG_GENERATION_MAX_SIZE);
 	public static final IAggregator<IQuantity, ?> NEW_RATIO_MIN = min(NEW_RATIO.getName(), null,
 			GC_CONF_YOUNG_GENERATION, NEW_RATIO);
 	public static final IAggregator<IQuantity, ?> TENURING_THRESHOLD_INITIAL_MIN = min(
@@ -250,12 +253,16 @@ public final class JdkAggregators {
 	public static final IAggregator<IQuantity, ?> FILE_READ_SIZE = Aggregators.sum(
 			Messages.getString(Messages.AGGR_FILE_READ_SIZE), Messages.getString(Messages.AGGR_FILE_READ_SIZE_DESC),
 			FILE_READ, IO_FILE_BYTES_READ);
+	public static final IAggregator<Boolean, ?> FILE_FORCE_METADATA = or(FILE_FORCE, IO_FILE_FORCE_METADATA);
 	public static final IAggregator<IQuantity, ?> FILE_WRITE_COUNT = Aggregators.count(
 			Messages.getString(Messages.AGGR_FILE_WRITE_COUNT), Messages.getString(Messages.AGGR_FILE_WRITE_COUNT_DESC),
 			JdkFilters.FILE_WRITE);
 	public static final IAggregator<IQuantity, ?> FILE_READ_COUNT = Aggregators.count(
 			Messages.getString(Messages.AGGR_FILE_READ_COUNT), Messages.getString(Messages.AGGR_FILE_READ_COUNT_DESC),
 			JdkFilters.FILE_READ);
+	public static final IAggregator<IQuantity, ?> FILE_FORCE_COUNT = Aggregators.count(
+			Messages.getString(Messages.AGGR_FILE_FORCE_COUNT), Messages.getString(Messages.AGGR_FILE_FORCE_COUNT_DESC),
+			JdkFilters.FILE_FORCE);
 	public static final IAggregator<IQuantity, ?> ERROR_COUNT = Aggregators.count(
 			Messages.getString(Messages.AGGR_ERROR_COUNT), Messages.getString(Messages.AGGR_ERROR_COUNT_DESC),
 			JdkFilters.ERRORS);
@@ -279,7 +286,7 @@ public final class JdkAggregators {
 			Messages.getString(Messages.AGGR_SOCKET_WRITE_SIZE_DESC), SOCKET_WRITE, IO_SOCKET_BYTES_WRITTEN);
 	public static final IAggregator<IQuantity, ?> SOCKET_READ_SIZE = Aggregators.sum(
 			Messages.getString(Messages.AGGR_SOCKET_READ_SIZE), Messages.getString(Messages.AGGR_SOCKET_READ_SIZE_DESC),
-			SOCKET_READ, IO_SOCKET_BYTES_READ);
+			SOCKET_READ, IO_SOCKET_BYTES_READ, (value -> value >= 0));
 	public static final IAggregator<IQuantity, ?> SOCKET_WRITE_COUNT = Aggregators.count(
 			Messages.getString(Messages.AGGR_SOCKET_WRITE_COUNT),
 			Messages.getString(Messages.AGGR_SOCKET_WRITE_COUNT_DESC), JdkFilters.SOCKET_WRITE);
@@ -381,6 +388,11 @@ public final class JdkAggregators {
 	public static final IAggregator<IQuantity, ?> STDDEV_BLOCKED_TIME = Aggregators.stddevp(
 			Messages.getString(Messages.AGGR_STDDEV_BLOCKED_TIME),
 			Messages.getString(Messages.AGGR_STDDEV_BLOCKED_TIME_DESC), DURATION);
+	public static final IAggregator<IQuantity, ?> TOTAL_INFLATED_COUNT = Aggregators.count(
+			Messages.getString(Messages.AGGR_TOTAL_INFLATED_COUNT),
+			Messages.getString(Messages.AGGR_TOTAL_INFLATED_COUNT_DESC), JdkFilters.MONITOR_INFLATE);
+	public static final IAggregator<String, ?> MONITOR_INFLATE_REASON = distinctAsString(JdkTypeIDs.MONITOR_INFLATE,
+			JdkAttributes.INFLATION_REASON);
 	public static final IAggregator<IQuantity, ?> ALLOC_INSIDE_TLAB_AVG = Aggregators.avg(
 			Messages.getString(Messages.AGGR_ALLOC_INSIDE_TLAB_AVG),
 			Messages.getString(Messages.AGGR_ALLOC_INSIDE_TLAB_AVG_DESC), JdkTypeIDs.ALLOC_INSIDE_TLAB,
