@@ -1,10 +1,10 @@
 /*
- * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * The contents of this file are subject to the terms of either the Universal Permissive License
- * v 1.0 as shown at http://oss.oracle.com/licenses/upl
+ * v 1.0 as shown at https://oss.oracle.com/licenses/upl
  *
  * or the following license:
  *
@@ -94,6 +94,8 @@ public class Messages {
 	public static final String AGGR_FILE_WRITE_COUNT_DESC = "AGGR_FILE_WRITE_COUNT_DESC"; //$NON-NLS-1$
 	public static final String AGGR_FILE_WRITE_SIZE = "AGGR_FILE_WRITE_SIZE"; //$NON-NLS-1$
 	public static final String AGGR_FILE_WRITE_SIZE_DESC = "AGGR_FILE_WRITE_SIZE_DESC"; //$NON-NLS-1$
+	public static final String AGGR_FILE_FORCE_COUNT = "AGGR_FILE_FORCE_COUNT"; //$NON-NLS-1$
+	public static final String AGGR_FILE_FORCE_COUNT_DESC = "AGGR_FILE_FORCE_COUNT_DESC"; //$NON-NLS-1$
 	public static final String AGGR_FIRST_ATTRIBUTE = "AGGR_FIRST_ATTRIBUTE"; //$NON-NLS-1$
 	public static final String AGGR_FIRST_ATTRIBUTE_DESC = "AGGR_FIRST_ATTRIBUTE_DESC"; //$NON-NLS-1$
 	public static final String AGGR_FLR_DATA_LOST_SIZE = "AGGR_FLR_DATA_LOST_SIZE"; //$NON-NLS-1$
@@ -186,6 +188,8 @@ public class Messages {
 	public static final String AGGR_THROWABLES_COUNT_DESC = "AGGR_THROWABLES_COUNT_DESC"; //$NON-NLS-1$
 	public static final String AGGR_TOTAL_BLOCKED_COUNT = "AGGR_TOTAL_BLOCKED_COUNT"; //$NON-NLS-1$
 	public static final String AGGR_TOTAL_BLOCKED_COUNT_DESC = "AGGR_TOTAL_BLOCKED_COUNT_DESC"; //$NON-NLS-1$
+	public static final String AGGR_TOTAL_INFLATED_COUNT = "AGGR_TOTAL_INFLATED_COUNT"; //$NON-NLS-1$
+	public static final String AGGR_TOTAL_INFLATED_COUNT_DESC = "AGGR_TOTAL_INFLATED_COUNT_DESC"; //$NON-NLS-1$
 	public static final String AGGR_TOTAL_BLOCKED_TIME = "AGGR_TOTAL_BLOCKED_TIME"; //$NON-NLS-1$
 	public static final String AGGR_TOTAL_BLOCKED_TIME_DESC = "AGGR_TOTAL_BLOCKED_TIME_DESC"; //$NON-NLS-1$
 	public static final String AGGR_TOTAL_GC_PAUSE = "AGGR_TOTAL_GC_PAUSE"; //$NON-NLS-1$
@@ -201,6 +205,16 @@ public class Messages {
 	public static final String AGGR_VM_OPERATION_DURATION = "AGGR_VM_OPERATION_DURATION"; //$NON-NLS-1$
 	public static final String AGGR_VM_OPERATION_DURATION_DESC = "AGGR_VM_OPERATION_DURATION_DESC"; //$NON-NLS-1$
 	public static final String ATTR_ADAPTORS = "ATTR_ADAPTORS"; //$NON-NLS-1$
+	public static final String ATTR_AGENT_DYNAMIC = "ATTR_AGENT_DYNAMIC"; //$NON-NLS-1$
+	public static final String ATTR_AGENT_DYNAMIC_DESC = "ATTR_AGENT_DYNAMIC_DESC"; //$NON-NLS-1$;
+	public static final String ATTR_AGENT_INITIALIZATION_TIME = "ATTR_AGENT_INITIALIZATION_TIME"; //$NON-NLS-1$
+	public static final String ATTR_AGENT_INITIALIZATION_TIME_DESC = "ATTR_AGENT_INITIALIZATION_TIME_DESC"; //$NON-NLS-1$;
+	public static final String ATTR_AGENT_INITIALIZATION_DURATION = "ATTR_AGENT_INITIALIZATION_DURATION"; //$NON-NLS-1$;
+	public static final String ATTR_AGENT_INITIALIZATION_DURATION_DESC = "ATTR_AGENT_INITIALIZATION_DURATION_DESC"; //$NON-NLS-1$;
+	public static final String ATTR_AGENT_NAME = "ATTR_AGENT_NAME";
+	public static final String ATTR_AGENT_NAME_DESC = "ATTR_AGENT_NAME_DESC";
+	public static final String ATTR_AGENT_OPTIONS = "ATTR_AGENT_OPTIONS"; //$NON-NLS-1$;
+	public static final String ATTR_AGENT_OPTIONS_DESC = "ATTR_AGENT_OPTIONS_DESC"; //$NON-NLS-1$;
 	public static final String ATTR_ALLOCATION_CLASS = "ATTR_ALLOCATION_CLASS"; //$NON-NLS-1$
 	public static final String ATTR_ALLOCATION_CLASS_DESC = "ATTR_ALLOCATION_CLASS_DESC"; //$NON-NLS-1$
 	public static final String ATTR_ALLOCATION_SIZE = "ATTR_ALLOCATION_SIZE"; //$NON-NLS-1$
@@ -281,6 +295,12 @@ public class Messages {
 	public static final String ATTR_EXPLICIT_GC_DISABLED_DESC = "ATTR_EXPLICIT_GC_DISABLED_DESC"; //$NON-NLS-1$
 	public static final String ATTR_EXPORTED_PACKAGE = "ATTR_EXPORTED_PACKAGE"; //$NON-NLS-1$
 	public static final String ATTR_EXPORTING_MODULE = "ATTR_EXPORTING_MODULE"; //$NON-NLS-1$
+	public static final String ATTR_FINALIZABLE_CLASS = "ATTR_FINALIZABLE_CLASS"; //$NON-NLS-1$
+	public static final String ATTR_FINALIZABLE_CLASS_DESC = "ATTR_FINALIZABLE_CLASS_DESC"; //$NON-NLS-1$
+	public static final String ATTR_FINALIZABLE_CLASS_NAME = "ATTR_FINALIZABLE_CLASS_NAME"; //$NON-NLS-1$
+	public static final String ATTR_FINALIZABLE_CLASS_NAME_DESC = "ATTR_FINALIZABLE_CLASS_NAME_DESC"; //$NON-NLS-1$
+	public static final String ATTR_TOTAL_FINALIZERS_RUN = "ATTR_TOTAL_FINALIZERS_RUN"; //$NON-NLS-1$
+	public static final String ATTR_TOTAL_FINALIZERS_RUN_DESC = "ATTR_TOTAL_FINALIZERS_RUN_DESC"; //$NON-NLS-1$
 	public static final String ATTR_FLAG_NAME = "ATTR_FLAG_NAME"; //$NON-NLS-1$
 	public static final String ATTR_FLAG_NEW_VALUE_BOOLEAN = "ATTR_FLAG_NEW_VALUE BOOLEAN"; //$NON-NLS-1$
 	public static final String ATTR_FLAG_NEW_VALUE_NUMBER = "ATTR_FLAG_NEW_VALUE_NUMBER"; //$NON-NLS-1$
@@ -325,6 +345,7 @@ public class Messages {
 	public static final String ATTR_GC_METASPACE_USED_DESC = "ATTR_GC_METASPACE_USED_DESC"; //$NON-NLS-1$
 	public static final String ATTR_GC_NAME = "ATTR_GC_NAME"; //$NON-NLS-1$
 	public static final String ATTR_GC_NAME_DESC = "ATTR_GC_NAME_DESC"; //$NON-NLS-1$
+	public static final String ATTR_GC_PAUSE_TARGET = "ATTR_GC_PAUSE_TARGET"; //$NON-NLS-1$
 	public static final String ATTR_GC_PHASE_NAME = "ATTR_GC_PHASE_NAME"; //$NON-NLS-1$
 	public static final String ATTR_GC_ROOT = "ATTR_GC_ROOT"; //$NON-NLS-1$
 	public static final String ATTR_GC_ROOT_DESC = "ATTR_GC_ROOT_DESC"; //$NON-NLS-1$
@@ -332,6 +353,10 @@ public class Messages {
 	public static final String ATTR_GC_SUM_OF_PAUSES_DESC = "ATTR_GC_SUM_OF_PAUSES_DESC"; //$NON-NLS-1$
 	public static final String ATTR_GC_THRESHOLD = "ATTR_GC_THRESHOLD"; //$NON-NLS-1$
 	public static final String ATTR_GC_THRESHOLD_DESC = "ATTR_GC_THRESHOLD_DESC"; //$NON-NLS-1$
+	public static final String ATTR_GC_TIME = "ATTR_GC_TIME"; //$NON-NLS-1$
+	public static final String ATTR_GC_TIME_REAL = "ATTR_GC_TIME_REAL"; //$NON-NLS-1$
+	public static final String ATTR_GC_TIME_SYSTEM = "ATTR_GC_TIME_SYSTEM"; //$NON-NLS-1$
+	public static final String ATTR_GC_TIME_USER = "ATTR_GC_TIME_USER"; //$NON-NLS-1$
 	public static final String ATTR_GC_TIME_RATIO = "ATTR_GC_TIME_RATIO"; //$NON-NLS-1$
 	public static final String ATTR_GC_TIME_RATIO_DESC = "ATTR_GC_TIME_RATIO_DESC"; //$NON-NLS-1$
 	public static final String ATTR_GC_WHEN = "ATTR_GC_WHEN"; //$NON-NLS-1$
@@ -355,6 +380,8 @@ public class Messages {
 	public static final String ATTR_IO_ADDRESS = "ATTR_IO_ADDRESS"; //$NON-NLS-1$
 	public static final String ATTR_IO_FILE_BYTES_READ = "ATTR_IO_FILE_BYTES_READ"; //$NON-NLS-1$
 	public static final String ATTR_IO_FILE_BYTES_READ_DESC = "ATTR_IO_FILE_BYTES_READ_DESC"; //$NON-NLS-1$
+	public static final String ATTR_IO_FILE_FORCE_METADATA = "ATTR_IO_FILE_FORCE_METADATA"; //$NON-NLS-1$
+	public static final String ATTR_IO_FILE_FORCE_METADATA_DESC = "ATTR_IO_FILE_FORCE_METADATA_DESC"; //$NON-NLS-1$
 	public static final String ATTR_IO_FILE_BYTES_WRITTEN = "ATTR_IO_FILE_BYTES_WRITTEN"; //$NON-NLS-1$
 	public static final String ATTR_IO_FILE_BYTES_WRITTEN_DESC = "ATTR_IO_FILE_BYTES_WRITTEN_DESC"; //$NON-NLS-1$
 	public static final String ATTR_IO_FILE_READ_EOF = "ATTR_IO_FILE_READ_EOF"; //$NON-NLS-1$
@@ -467,6 +494,10 @@ public class Messages {
 	public static final String ATTR_REVOKATION_LOCK_CLASS_DESC = "ATTR_REVOKATION_LOCK_CLASS_DESC"; //$NON-NLS-1$
 	public static final String ATTR_REVOKED_CLASS = "ATTR_REVOKED_CLASS"; //$NON-NLS-1$
 	public static final String ATTR_REVOKED_CLASS_DESC = "ATTR_REVOKED_CLASS_DESC"; //$NON-NLS-1$
+	public static final String ATTR_RSS_SIZE = "ATTR_RSS_SIZE"; //$NON-NLS-1$
+	public static final String ATTR_RSS_SIZE_DESC = "ATTR_RSS_SIZE_DESC"; //$NON-NLS-1$
+	public static final String ATTR_RSS_PEAK = "ATTR_RSS_PEAK"; //$NON-NLS-1$
+	public static final String ATTR_RSS_PEAK_DESC = "ATTR_RSS_PEAK_DESC"; //$NON-NLS-1$
 	public static final String ATTR_SAFEPOINT = "ATTR_SAFEPOINT"; //$NON-NLS-1$
 	public static final String ATTR_SAFEPOINT_DESC = "ATTR_SAFEPOINT_DESC"; //$NON-NLS-1$
 	public static final String ATTR_SAMPLE_WEIGHT = "ATTR_SAMPLE_WEIGHT"; //$NON-NLS-1$
@@ -514,6 +545,8 @@ public class Messages {
 	public static final String ATTR_YOUNG_GENERATION_MIN_SIZE = "ATTR_YOUNG_GENERATION_MIN_SIZE"; //$NON-NLS-1$
 	public static final String ATTR_SHUTDOWN_REASON = "ATTR_SHUTDOWN_REASON"; //$NON-NLS-1$
 	public static final String ATTR_SHUTDOWN_REASON_DESC = "ATTR_SHUTDOWN_REASON_DESC"; //$NON-NLS-1$
+	public static final String ATTR_INFLATION_REASON = "ATTR_INFLATION_REASON"; //$NON-NLS-1$
+	public static final String ATTR_INFLATION_REASON_DESC = "ATTR_INFLATION_REASON_DESC"; //$NON-NLS-1$
 	public static final String ATTR_SHUTDOWN_TIME = "ATTR_SHUTDOWN_TIME"; //$NON-NLS-1$
 	public static final String ATTR_SYSTEM_LOAD = "ATTR_SYSTEM_LOAD"; //$NON-NLS-1$
 	public static final String ATTR_SYSTEM_LOAD_DESC = "ATTR_SYSTEM_LOAD_DESC"; //$NON-NLS-1$
@@ -521,6 +554,14 @@ public class Messages {
 	public static final String ATTR_USER_LOAD_DESC = "ATTR_USER_LOAD_DESC"; //$NON-NLS-1$
 	public static final String ATTR_JAVA_THREAD = "ATTR_JAVA_THREAD"; //$NON-NLS-1$
 	public static final String ATTR_JAVA_THREAD_DESC = "ATTR_JAVA_THREAD_DESC"; //$NON-NLS-1$
+	public static final String ATTR_THREADS_ACCUMULATED_COUNT = "ATTR_THREADS_ACCUMULATED_COUNT";
+	public static final String ATTR_THREADS_ACCUMULATED_COUNT_DESC = "ATTR_THREADS_ACCUMULATED_COUNT_DESC";
+	public static final String ATTR_THREADS_ACTIVE_COUNT = "ATTR_THREADS_ACTIVE_COUNT";
+	public static final String ATTR_THREADS_ACTIVE_COUNT_DESC = "ATTR_THREADS_ACTIVE_COUNT_DESC";
+	public static final String ATTR_THREADS_DAEMON_COUNT = "ATTR_THREADS_DAEMON_COUNT";
+	public static final String ATTR_THREADS_DAEMON_COUNT_DESC = "ATTR_THREADS_DAEMON_COUNT_DESC";
+	public static final String ATTR_THREADS_PEAK_COUNT = "ATTR_THREADS_PEAK_COUNT";
+	public static final String ATTR_THREADS_PEAK_COUNT_DESC = "ATTR_THREADS_PEAK_COUNT_DESC";
 
 	private Messages() {
 	}
